# Transprint

**transprint** es una librería simple en Python que permite traducir tus prints automaticamente a cualquier idioma.

## Formas de Uso

puedes usar tranprint.print("") para traducir tu print al idioma del equipo que este ejecutando tu programa o puedes definir el idioma de salida asi: transprint.print("", destino="es")

## Instalación

```bash
pip install transprint
